@@ -14,7 +14,7 @@ use Data::Dumper;
 extends 'Business::CPI::Gateway::Base';
 with 'Business::CPI::Role::Gateway::FormCheckout';
 
-our $VERSION = '0.903'; # VERSION
+our $VERSION = '0.904'; # VERSION
 
 has '+checkout_url' => (
     default => sub { 'https://pagseguro.uol.com.br/v2/checkout/payment.html' },
@@ -104,11 +104,16 @@ sub get_and_parse_transactions {
         $self->get_transaction_query_url( $info )
     );
 
-    my @transactions = $xml->getChildrenByTagName('transactions')->get_node(1)->getChildrenByTagName('transaction');
+    my $results_in_this_page = $xml->getChildrenByTagName('resultsInThisPage')->string_value;
+
+    my @transactions = $results_in_this_page
+                     ? $xml->getChildrenByTagName('transactions')->get_node(1)->getChildrenByTagName('transaction')
+                     : ()
+                     ;
 
     return {
         current_page         => $xml->getChildrenByTagName('currentPage')->string_value,
-        results_in_this_page => $xml->getChildrenByTagName('resultsInThisPage')->string_value,
+        results_in_this_page => $results_in_this_page,
         total_pages          => $xml->getChildrenByTagName('totalPages')->string_value,
         transactions         => [
             map { $self->get_transaction_details( $_ ) }
@@ -298,7 +303,7 @@ Business::CPI::Gateway::PagSeguro - Business::CPI's PagSeguro driver
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 ATTRIBUTES
 
@@ -364,7 +369,7 @@ Renato CRON <rentocron@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by André Walker.
+This software is copyright (c) 2015 by André Walker.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
